@@ -36,7 +36,7 @@ def int73(freq, psd):
     return int73, integrand73
 
 
-def sensemon_range(freq, psd, m1=1.4, m2=1.4, horizon=False, integrate=True):
+def sensemon_range(freq, psd, m1=1.4, m2=1.4, horizon=False, integrate=True, detection_snr=DETECTION_SNR):
     """Detector inspiral range from closed form expression
 
     Masses `m1` and `m2` should be specified in solar masses (default:
@@ -59,7 +59,7 @@ def sensemon_range(freq, psd, m1=1.4, m2=1.4, horizon=False, integrate=True):
         i73 = integral
     else:
         i73 = integrand
-    val = theta / DETECTION_SNR \
+    val = theta / detection_snr \
         * waveform.habs_nsp_prefactor(M_chirp) \
         * np.sqrt(i73) / 2
     if integrate:
@@ -104,7 +104,7 @@ def find_root_redshift(func):
     zmin = 1e-8
     log_opt(zmin)
     # steadily shift the z range if we don't find a root
-    for zmax in [0.1, 1, 10, 100]:
+    for zmax in [0.1, 1, 10, 100, 1000]:
         log_opt(zmax)
         try:
             return scipy.optimize.brentq(func, zmin, zmax)
@@ -115,12 +115,11 @@ def find_root_redshift(func):
         raise RuntimeError(f"Could not find root of {func.__name__} inside z={zmax}.")
 
 
-def horizon_redshift(freq, psd, H=None, **params):
+def horizon_redshift(freq, psd, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector horizon redshift
 
     For the given detector noise PSD and waveform parameters return
-    the redshift at which the detection SNR would equal to the
-    DETECTION_SNR.
+    the redshift at which the signal SNR would equal `detection_snr`.
 
     Remaining keyword arguments are interpreted as waveform generation
     parameters (see waveform.gen_waveform()), or a pre-generated
@@ -131,11 +130,11 @@ def horizon_redshift(freq, psd, H=None, **params):
     """
     H = __H_from_args(freq, psd, H, params)
     def opt_SNR_z(z):
-        return H.SNR(psd, z) - DETECTION_SNR
+        return H.SNR(psd, z) - detection_snr
     return find_root_redshift(opt_SNR_z)
 
 
-def horizon(freq, psd, H=None, **params):
+def horizon(freq, psd, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector horizon distance in Mpc
 
     See horizon_redshift().
@@ -144,16 +143,16 @@ def horizon(freq, psd, H=None, **params):
 
     """
     H = __H_from_args(freq, psd, H, params)
-    zhor = horizon_redshift(freq, psd, H=H)
+    zhor = horizon_redshift(freq, psd, detection_snr=detection_snr, H=H)
     return H.cosmo.luminosity_distance(zhor)
 
 
-def volume(freq, psd, z_hor=None, H=None, **params):
+def volume(freq, psd, z_hor=None, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector redshift-corrected comoving volume
 
     For the given detector noise PSD and waveform parameters return
     the redshift-corrected, comoving volume in Mpc^3 within which all
-    sources would have SNR greater than the DETECTION_SNR.
+    sources would have SNR greater than `detection_snr`.
 
     Remaining keyword arguments are interpreted as waveform generation
     parameters (see waveform.gen_waveform()), or a pre-generated
@@ -182,7 +181,7 @@ def volume(freq, psd, z_hor=None, H=None, **params):
     # beyond.
 
     if not z_hor:
-        z_hor = horizon_redshift(freq, psd, H=H)
+        z_hor = horizon_redshift(freq, psd, detection_snr=detection_snr, H=H)
 
     # create a Gauss-Legendre quadrature for the integration:
     # https://en.wikipedia.org/wiki/Gaussian_quadrature#Gauss.E2.80.93Legendre_quadrature
@@ -195,7 +194,7 @@ def volume(freq, psd, z_hor=None, H=None, **params):
 
     # detectability fraction
     snrs = np.array([H.SNR(psd, zz) for zz in z])
-    f = np.array([ang_avg(snr / DETECTION_SNR) for snr in snrs])
+    f = np.array([ang_avg(snr / detection_snr) for snr in snrs])
     # logger.debug('f = {}'.format(f))
 
     # comoving volume density, e.g. dVc/dz 1/(1+z)
@@ -209,13 +208,13 @@ def volume(freq, psd, z_hor=None, H=None, **params):
     return V
 
 
-def range(freq, psd, z_hor=None, H=None, **params):
+def range(freq, psd, z_hor=None, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector redshift-corrected comoving range in Mpc
 
     For the given detector noise PSD and waveform parameters return
     the redshift-corrected, comoving distance in Mpc at which the
-    detection SNR would equal to the DETECTION_SNR, i.e. the radius of
-    the Euclidean sphere given by volume().
+    signal SNR would equal `detection_snr`, i.e. the radius of the
+    Euclidean sphere given by volume().
 
     Remaining keyword arguments are interpreted as waveform generation
     parameters (see waveform.gen_waveform()), or a pre-generated
@@ -224,16 +223,16 @@ def range(freq, psd, z_hor=None, H=None, **params):
     @returns distance in Mpc as a float
 
     """
-    V = volume(freq, psd, z_hor=z_hor, H=H, **params)
+    V = volume(freq, psd, z_hor=z_hor, detection_snr=detection_snr, H=H, **params)
     return util.v2r(V)
 
 
-def response_frac_redshift(frac, freq, psd, H=None, **params):
+def response_frac_redshift(frac, freq, psd, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector response fraction redshift
 
     For the given detector noise PSD and waveform parameters return
     the redshift at which the specified fraction of sources would be
-    detected (SNR >= DETECTION_SNR) if they were all placed at that
+    detected (SNR >= `detection_snr`) if they were all placed at that
     distance.  Assumes a uniform distribution of sources.
 
     Remaining keyword arguments are interpreted as waveform generation
@@ -246,12 +245,12 @@ def response_frac_redshift(frac, freq, psd, H=None, **params):
     H = __H_from_args(freq, psd, H, params)
     def opt_f_z(z):
         snr = H.SNR(psd, z)
-        f = ang_avg(snr / DETECTION_SNR)
+        f = ang_avg(snr / detection_snr)
         return f - frac
     return find_root_redshift(opt_f_z)
 
 
-def response_frac(frac, freq, psd, H=None, **params):
+def response_frac(frac, freq, psd, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector response fraction distance in Mpc
 
     See reach_frac_redshift().
@@ -260,11 +259,11 @@ def response_frac(frac, freq, psd, H=None, **params):
 
     """
     H = __H_from_args(freq, psd, H, params)
-    z = response_frac_redshift(frac, freq, psd, H=H)
+    z = response_frac_redshift(frac, freq, psd, detection_snr=detection_snr, H=H)
     return H.cosmo.luminosity_distance(z)
 
 
-def reach_frac_redshift(frac, freq, psd, cvol=None, H=None, **params):
+def reach_frac_redshift(frac, freq, psd, cvol=None, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector detectability fraction reach redshift
 
     For the given detector noise PSD and waveform parameters return
@@ -280,14 +279,14 @@ def reach_frac_redshift(frac, freq, psd, cvol=None, H=None, **params):
     """
     H = __H_from_args(freq, psd, H, params)
     if not cvol:
-        cvol = volume(freq, psd, H=H)
+        cvol = volume(freq, psd, detection_snr=detection_snr, H=H)
     def opt_V_z(z):
-        V = volume(freq, psd, z_hor=z, H=H)
+        V = volume(freq, psd, detection_snr=detection_snr, z_hor=z, H=H)
         return frac - V/cvol
     return find_root_redshift(opt_V_z)
 
 
-def reach_frac(frac, freq, psd, cvol=None, H=None, **params):
+def reach_frac(frac, freq, psd, cvol=None, detection_snr=DETECTION_SNR, H=None, **params):
     """Detector detectability fraction reach in Mpc
 
     See reach_frac_redshift().
@@ -296,11 +295,11 @@ def reach_frac(frac, freq, psd, cvol=None, H=None, **params):
 
     """
     H = __H_from_args(freq, psd, H, params)
-    z = reach_frac_redshift(frac, freq, psd, cvol=cvol, H=H)
+    z = reach_frac_redshift(frac, freq, psd, cvol=cvol, detection_snr=detection_snr, H=H)
     return H.cosmo.luminosity_distance(z)
 
 
-def cosmological_ranges(freq, psd, H=None, **params):
+def cosmological_ranges(freq, psd, detection_snr=DETECTION_SNR, H=None, **params):
     """Calculate various cosmology-corrected detector distance measures
 
     The following range values are calculated:
@@ -327,20 +326,20 @@ def cosmological_ranges(freq, psd, H=None, **params):
     """
     H = __H_from_args(freq, psd, H, params)
 
-    hor_z = horizon_redshift(freq, psd, H=H)
+    hor_z = horizon_redshift(freq, psd, detection_snr=detection_snr, H=H)
     hor = H.cosmo.luminosity_distance(hor_z)
 
-    cvol = volume(freq, psd, z_hor=hor_z, H=H)
+    cvol = volume(freq, psd, z_hor=hor_z, detection_snr=detection_snr, H=H)
     crange = util.v2r(cvol)
 
-    response_z_50 = response_frac_redshift(0.5, freq, psd, H=H)
+    response_z_50 = response_frac_redshift(0.5, freq, psd, detection_snr=detection_snr, H=H)
     response_50 = H.cosmo.luminosity_distance(response_z_50)
-    response_z_10 = response_frac_redshift(0.1, freq, psd, H=H)
+    response_z_10 = response_frac_redshift(0.1, freq, psd, detection_snr=detection_snr, H=H)
     response_10 = H.cosmo.luminosity_distance(response_z_10)
 
-    reach_z_50 = reach_frac_redshift(0.5, freq, psd, cvol=cvol, H=H)
+    reach_z_50 = reach_frac_redshift(0.5, freq, psd, cvol=cvol, detection_snr=detection_snr, H=H)
     reach_50 = H.cosmo.luminosity_distance(reach_z_50)
-    reach_z_90 = reach_frac_redshift(0.9, freq, psd, cvol=cvol, H=H)
+    reach_z_90 = reach_frac_redshift(0.9, freq, psd, cvol=cvol, detection_snr=detection_snr, H=H)
     reach_90 = H.cosmo.luminosity_distance(reach_z_90)
 
     return collections.OrderedDict([
@@ -358,7 +357,7 @@ def cosmological_ranges(freq, psd, H=None, **params):
         ])
 
 
-def all_ranges(freq, psd, H=None, **params):
+def all_ranges(freq, psd, detection_snr=DETECTION_SNR, H=None, **params):
     """Calculate all ranges, cosmological and sensemon
 
     Returns a tuple (metrics, params) where `metrics` is a dictionary
@@ -367,11 +366,11 @@ def all_ranges(freq, psd, H=None, **params):
 
     """
     H = __H_from_args(freq, psd, H, params)
-    metrics = cosmological_ranges(freq, psd, H=H)
+    metrics = cosmological_ranges(freq, psd, detection_snr=detection_snr, H=H)
     metrics['sensemon_range'] = \
-        (sensemon_range(freq, psd, H.params['m1'], H.params['m2']),
+        (sensemon_range(freq, psd, H.params['m1'], H.params['m2'], detection_snr=detection_snr),
          'Mpc')
     metrics['sensemon_horizon'] = \
-        (sensemon_range(freq, psd, H.params['m1'], H.params['m2'], horizon=True),
+        (sensemon_range(freq, psd, H.params['m1'], H.params['m2'], detection_snr=detection_snr, horizon=True),
          'Mpc')
     return metrics, H
